@@ -187,7 +187,7 @@ bool DynamicTreeModel::dropMimeData(const QMimeData *data, Qt::DropAction action
 {
     Q_UNUSED(action);
     Q_UNUSED(_column);
-    QByteArray encoded = data->data(mimeTypes().first());
+    QByteArray encoded = data->data(mimeTypes().at(0));
 
     QHash<QModelIndex, QList<int> > movedItems;
     bool ok;
@@ -334,7 +334,7 @@ QMimeData *DynamicTreeModel::mimeData(const QModelIndexList &indexes) const
             itemData.append('\0');
         }
     }
-    data->setData(mimeTypes().first(), itemData);
+    data->setData(mimeTypes().at(0), itemData);
     return data;
 }
 
@@ -351,11 +351,14 @@ QList<int> DynamicTreeModel::indexToPath(const QModelIndex &_idx) const
 
 QModelIndexList DynamicTreeModel::match(const QModelIndex &start, int role, const QVariant &value, int hits, Qt::MatchFlags flags) const
 {
-    if (role != DynamicTreeModelId) {
+    if (role != DynamicTreeModelId && role != Qt::DisplayRole) {
         return QAbstractItemModel::match(start, role, value, hits, flags);
     }
 
     qint64 id = value.toLongLong();
+    if (role == Qt::DisplayRole) {
+        id = m_items.key(value.toString());
+      }
 
     QHash<qint64, QList<QList<qint64> > >::const_iterator it = m_childItems.constBegin();
     const QHash<qint64, QList<QList<qint64> > >::const_iterator end = m_childItems.constEnd();
